import sys, os
import numpy as np
import BioNetInput, BioNetTrajectory

# Data
numRuns = 3
#ffs = [0.72,0.91, 1.0]
ffs = [1.00, 0.91, 0.72]

# Other data
numNodes = 5000
vf = 0.074
radius = 3.5
boxDims = np.power((4.0/3.0) * np.pi * numNodes / vf,0.3333) * radius
ln = 10.7368
kbt = 4.11
drag = 6 * np.pi * radius
kCross = 100

# Loop over variables (including numRuns)
for ff in ffs:

	for nr in range(numRuns):

		# Get initial script
		iFname = "../input/BSAHydrogel_ff%.3f_ThermalStericRelax_Run%d.xml" % (ff,nr)

		inp = BioNetInput.BioNetInput()
		inp.load(iFname)

		# Get final trajectory frame
		tFname = "../output/BSAHydrogel_ff%.3f_ThermalStericRelax_Run%d.bntrj" % (ff,nr)

		traj = BioNetTrajectory.BioNetTrajectory()
		traj.loadFinalFrame(tFname, inScript=inp)

		"""
		# Alter the 18 bead structure to a tetrahedron
#                                <site name="SiteA" type="point" position="0.82,0.00,-0.58" rate="1000.00"/>
 #                               <site name="SiteB" type="point" position="-0.82,0.00,-0.58" rate="1000.00"/>
  #                              <site name="SiteC" type="point" position="0.00,0.82,0.58" rate="1000.00"/>
   #                             <site name="SiteD" type="point" position="0.00,-0.82,0.58" rate="1000.00"/>

		inp.protein[1].numSites = 4
		inp.protein[1].site = inp.protein[1].site[:4]

		inp.protein[1].site[0].position = np.array([0.82,0.00,-0.58])
		inp.protein[1].site[1].position = np.array([-0.82,0.00,-0.58])
		inp.protein[1].site[2].position = np.array([0.00,0.82,0.58])
		inp.protein[1].site[3].position = np.array([0.82,-0.82,0.58])
		"""

		# Alter times (half box of diffusion / 20uS)
		drag = 6 * np.pi * radius
#		inp.params.simTime = np.max([0.5 * np.power(boxDims / 2.0, 2) * drag / kbt,20000])
		inp.params.simTime = 10000
		inp.params.timePerFrame = int(inp.params.simTime / 1000.0)
		inp.params.dt = drag / (2 * kCross * 10)

		if inp.params.timePerFrame < inp.params.dt:
			inp.params.timePerFrame = inp.params.dt

		# Modify the input script
		for i in range(inp.numNodes):
			inp.node[i].pos = traj.frame[0].pos[i]
			inp.node[i].orientation = traj.frame[0].euler[i]

		# Alter to PBC
		inp.box.BC = "PBC"

		# Write to output
		oFname =  "../input/BSAHydrogel_ff%.3f_Kinetics_Run%d.xml" % (ff,nr)
		inp.writeToFile(oFname)
	

