import sys, os
import numpy as np

# Data
numRuns = 3
#ffs = [0.72,0.91, 1.00]
ffs = [0.72,0.91, 1.00]

# Other data
numTotalBSA = 5000
nodesInChain = 20
numSegments = nodesInChain - 1

vf = 0.074
radius = 3.3
boxDims = np.power((4.0/3.0) * np.pi * numTotalBSA / vf,0.3333) * radius
ln = 10.7368
kbt = 4.11
drag = 6 * np.pi * radius
crossK = 100

# Get template
with open("../input/templates/BSAHydrogel_ff0.720_Template.xml", "r") as fin:
	lines = fin.readlines()

# Write a file for each parameter
for ff in ffs:
	for nr in range(numRuns):

		# Get a file to write to
		oFname = "../input/BSAHydrogel_ff%.3f_Relax_Run%d.xml" % (ff, nr)
		fout = open(oFname, "w")

		# Write all components
		sIndex = 0
		index = 0
		for line in lines[sIndex:]:
			if "<params>" in line:
				fout.write(line)
				sIndex = index
				break

			fout.write(line)
			index += 1

		# Make parameters
		time = (boxDims / 20.0) ** 2 / (2 * kbt / drag)
		fout.write('\t\t\t<param name="dt" value = "%f"/>\n' % (drag / (2 * crossK)))
		fout.write('\t\t\t<param name="simTime" value = "%f"/>\n' % (time))
		fout.write('\t\t\t<param name="timePerFrame" value = "%f"/>\n' % (time / 20.0))
		fout.write("\t\t</params>\n")
		fout.write("\t\t<nodes>\n")
		
		# Do a volume fractions worth of BSA (each BSA is two nodes)
		numBSA = int(numTotalBSA * ff)
		for i in range(numBSA):

			# Get first as random pos in box
			pos = [np.random.uniform(radius,boxDims - radius),np.random.uniform(radius,boxDims - radius),np.random.uniform(radius,boxDims - radius)]
			while pos[0] + 3 * radius + 0.15 > boxDims or pos[1] + radius > boxDims or pos[2] + radius > boxDims:
				pos = [np.random.uniform(radius,boxDims - radius),np.random.uniform(radius,boxDims - radius),np.random.uniform(radius,boxDims - radius)]

			fout.write('\t\t\t<node template="BSA" pos="%f,%f,%f" vel="0,0,0"/>\n' % (pos[0], pos[1], pos[2]))

		# Do the remainder as alpha chains
		numChains = int(numTotalBSA - numBSA)
		for i in range(numChains):
			
			# Get first as random pos in box
			pos = [np.random.uniform(0,boxDims),np.random.uniform(0,boxDims),np.random.uniform(0,boxDims)]
			fout.write('\t\t\t<node template="AminoAcidNode" pos="%f,%f,%f" vel="0,0,0"/>\n' % (pos[0], pos[1], pos[2]))

			for j in range(numSegments):

				# Get the next numSegments as random rotations
				trans = np.array([np.random.uniform(-1,1),np.random.uniform(-1,1),np.random.uniform(-1,1)])
				trans *= ln / np.linalg.norm(trans)

				pos += trans
				while np.any(pos > boxDims) or np.any(pos < 0):
					pos -= trans
					trans = np.array([np.random.uniform(-1,1),np.random.uniform(-1,1),np.random.uniform(-1,1)])
					trans *= ln / np.linalg.norm(trans)

					pos += trans

				fout.write('\t\t\t<node template="AminoAcidNode" pos="%f,%f,%f" vel="0,0,0"/>\n' % (pos[0], pos[1], pos[2]))

		# Now connections
		fout.write("\t\t</nodes>\n")
		fout.write("\t\t<connections>\n")

		# Connect each chain
		for i in range(numChains):
			for j in range(numSegments):
				fout.write('\t\t\t<connection template="AminoAcidLinker" nodes="%d,%d" sites="0,0"/>\n' % (numBSA + nodesInChain * i + j,numBSA + nodesInChain * i + j + 1))

		# Write remainder
		sIndex = 0
		index = 0
		for line in lines[sIndex:]:
			if "</connections>" in line:
				sIndex = index
				break
			index += 1

		# Write all components
		for line in lines[sIndex:]:
			if('<param name="dimensions"') in line:
				fout.write('\t\t\t<param name="dimensions" value="%f,%f,%f"/>\n' % (boxDims,boxDims,boxDims))
			else:
				fout.write(line)

		fout.close()
