import sys, os
import numpy as np
import BioNetInput, BioNetTrajectory

# Data
numRuns = 3
#ffs = [0.72,1.0]
ffs = [0.72]

# Other data
numNodes = 5000
vf = 0.074
radius = 3.3
boxDims = np.power((4.0/3.0) * np.pi * numNodes / vf,0.3333) * radius
ln = 10.7368
kbt = 4.11
drag = 6 * np.pi * radius

# Loop over variables (including numRuns)
for ff in ffs:

	for nr in range(numRuns):

		# Get initial script
		iFname = "../input/BSAHydrogel_ff%.3f_Relax_Run%d.xml" % (ff,nr)

		inp = BioNetInput.BioNetInput()
		inp.load(iFname)

		# Get final trajectory frame
		tFname = "../output/BSAHydrogel_ff%.3f_Relax_Run%d.bntrj" % (ff,nr)

		traj = BioNetTrajectory.BioNetTrajectory()
		traj.loadFinalFrame(tFname, inScript=inp)

		# Alter times (2 particles of diffusion)
		drag = 6 * np.pi * radius
		inp.params.simTime = 0.5 * np.power(2 * radius, 2) * drag / kbt
		inp.params.timePerFrame = int(inp.params.simTime / 10.0)
		inp.params.dt /= 10.0	# Lower for steric
 
		if inp.params.timePerFrame < inp.params.dt:
			inp.params.timePerFrame = inp.params.dt

		# Modify the input script
		for i in range(inp.numNodes):
			inp.node[i].pos = traj.frame[0].pos[i]
			inp.node[i].orientation = traj.frame[0].euler[i]

		# Write to output
		oFname =  "../input/BSAHydrogel_ff%.3f_StericRelax_Run%d.xml" % (ff,nr)
		inp.writeToFile(oFname)
	

